halt

package
v0.0.0-...-f1b319b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 12, 2023 License: GPL-3.0 Imports: 6 Imported by: 0

Documentation

Overview

Package halt exposes a convenience method to deal with graceful shutdowns.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Halter

type Halter interface {
	// Wait should block until a shutdown is requested.
	Wait()
}

Halter will be used to wait for shutdown requests.

func New

func New(ctx context.Context, log logger.Log) (context.Context, Halter)

New configures and returns the context to use when shutting down.

Jump to